pub struct Config { /* private fields */ }Expand description
Configuration for Flow type generation.
Implementations
Sourceimpl Config
impl Config
Sourcepub fn from_env() -> Self
pub fn from_env() -> Self
Read config from environment variables.
| Variable | Default |
|---|---|
FLOW_RS_EXPORT_DIR | ./bindings |
Sourcepub fn with_out_dir(self, dir: impl Into<PathBuf>) -> Self
pub fn with_out_dir(self, dir: impl Into<PathBuf>) -> Self
Set the export directory.
Sourcepub fn with_array_tuple_limit(self, limit: usize) -> Self
pub fn with_array_tuple_limit(self, limit: usize) -> Self
Set the maximum size of arrays up to which they are treated as Flow tuples.
Arrays beyond this size will instead result in a $ReadOnlyArray<T>.
Default: 64
Sourcepub fn array_tuple_limit(&self) -> usize
pub fn array_tuple_limit(&self) -> usize
Return the maximum size of arrays treated as tuples.